# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PropertyFeaturesDescriptiveEquipments(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'furniture': 'bool',
        'fireplace': 'bool',
        'air_conditioning': 'bool',
        'adsl': 'bool',
        'cable': 'bool',
        'fiber': 'bool',
        'elevator': 'bool',
        'digicode': 'bool',
        'intercom': 'bool',
        'videophone': 'bool',
        'bike_area': 'bool',
        'two_wheel_park': 'bool',
        'disabled_access': 'bool'
    }

    attribute_map = {
        'furniture': 'FURNITURE',
        'fireplace': 'FIREPLACE',
        'air_conditioning': 'AIR_CONDITIONING',
        'adsl': 'ADSL',
        'cable': 'CABLE',
        'fiber': 'FIBER',
        'elevator': 'ELEVATOR',
        'digicode': 'DIGICODE',
        'intercom': 'INTERCOM',
        'videophone': 'VIDEOPHONE',
        'bike_area': 'BIKE_AREA',
        'two_wheel_park': 'TWO_WHEEL_PARK',
        'disabled_access': 'DISABLED_ACCESS'
    }

    def __init__(self, furniture=None, fireplace=None, air_conditioning=None, adsl=None, cable=None, fiber=None, elevator=None, digicode=None, intercom=None, videophone=None, bike_area=None, two_wheel_park=None, disabled_access=None):
        """
        PropertyFeaturesDescriptiveEquipments - a model defined in Swagger
        """

        self._furniture = None
        self._fireplace = None
        self._air_conditioning = None
        self._adsl = None
        self._cable = None
        self._fiber = None
        self._elevator = None
        self._digicode = None
        self._intercom = None
        self._videophone = None
        self._bike_area = None
        self._two_wheel_park = None
        self._disabled_access = None

        if furniture is not None:
          self.furniture = furniture
        if fireplace is not None:
          self.fireplace = fireplace
        if air_conditioning is not None:
          self.air_conditioning = air_conditioning
        if adsl is not None:
          self.adsl = adsl
        if cable is not None:
          self.cable = cable
        if fiber is not None:
          self.fiber = fiber
        if elevator is not None:
          self.elevator = elevator
        if digicode is not None:
          self.digicode = digicode
        if intercom is not None:
          self.intercom = intercom
        if videophone is not None:
          self.videophone = videophone
        if bike_area is not None:
          self.bike_area = bike_area
        if two_wheel_park is not None:
          self.two_wheel_park = two_wheel_park
        if disabled_access is not None:
          self.disabled_access = disabled_access

    @property
    def furniture(self):
        """
        Gets the furniture of this PropertyFeaturesDescriptiveEquipments.

        :return: The furniture of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._furniture

    @furniture.setter
    def furniture(self, furniture):
        """
        Sets the furniture of this PropertyFeaturesDescriptiveEquipments.

        :param furniture: The furniture of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._furniture = furniture

    @property
    def fireplace(self):
        """
        Gets the fireplace of this PropertyFeaturesDescriptiveEquipments.

        :return: The fireplace of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._fireplace

    @fireplace.setter
    def fireplace(self, fireplace):
        """
        Sets the fireplace of this PropertyFeaturesDescriptiveEquipments.

        :param fireplace: The fireplace of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._fireplace = fireplace

    @property
    def air_conditioning(self):
        """
        Gets the air_conditioning of this PropertyFeaturesDescriptiveEquipments.

        :return: The air_conditioning of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._air_conditioning

    @air_conditioning.setter
    def air_conditioning(self, air_conditioning):
        """
        Sets the air_conditioning of this PropertyFeaturesDescriptiveEquipments.

        :param air_conditioning: The air_conditioning of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._air_conditioning = air_conditioning

    @property
    def adsl(self):
        """
        Gets the adsl of this PropertyFeaturesDescriptiveEquipments.

        :return: The adsl of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._adsl

    @adsl.setter
    def adsl(self, adsl):
        """
        Sets the adsl of this PropertyFeaturesDescriptiveEquipments.

        :param adsl: The adsl of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._adsl = adsl

    @property
    def cable(self):
        """
        Gets the cable of this PropertyFeaturesDescriptiveEquipments.

        :return: The cable of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._cable

    @cable.setter
    def cable(self, cable):
        """
        Sets the cable of this PropertyFeaturesDescriptiveEquipments.

        :param cable: The cable of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._cable = cable

    @property
    def fiber(self):
        """
        Gets the fiber of this PropertyFeaturesDescriptiveEquipments.

        :return: The fiber of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._fiber

    @fiber.setter
    def fiber(self, fiber):
        """
        Sets the fiber of this PropertyFeaturesDescriptiveEquipments.

        :param fiber: The fiber of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._fiber = fiber

    @property
    def elevator(self):
        """
        Gets the elevator of this PropertyFeaturesDescriptiveEquipments.

        :return: The elevator of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._elevator

    @elevator.setter
    def elevator(self, elevator):
        """
        Sets the elevator of this PropertyFeaturesDescriptiveEquipments.

        :param elevator: The elevator of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._elevator = elevator

    @property
    def digicode(self):
        """
        Gets the digicode of this PropertyFeaturesDescriptiveEquipments.

        :return: The digicode of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._digicode

    @digicode.setter
    def digicode(self, digicode):
        """
        Sets the digicode of this PropertyFeaturesDescriptiveEquipments.

        :param digicode: The digicode of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._digicode = digicode

    @property
    def intercom(self):
        """
        Gets the intercom of this PropertyFeaturesDescriptiveEquipments.

        :return: The intercom of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._intercom

    @intercom.setter
    def intercom(self, intercom):
        """
        Sets the intercom of this PropertyFeaturesDescriptiveEquipments.

        :param intercom: The intercom of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._intercom = intercom

    @property
    def videophone(self):
        """
        Gets the videophone of this PropertyFeaturesDescriptiveEquipments.

        :return: The videophone of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._videophone

    @videophone.setter
    def videophone(self, videophone):
        """
        Sets the videophone of this PropertyFeaturesDescriptiveEquipments.

        :param videophone: The videophone of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._videophone = videophone

    @property
    def bike_area(self):
        """
        Gets the bike_area of this PropertyFeaturesDescriptiveEquipments.

        :return: The bike_area of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._bike_area

    @bike_area.setter
    def bike_area(self, bike_area):
        """
        Sets the bike_area of this PropertyFeaturesDescriptiveEquipments.

        :param bike_area: The bike_area of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._bike_area = bike_area

    @property
    def two_wheel_park(self):
        """
        Gets the two_wheel_park of this PropertyFeaturesDescriptiveEquipments.

        :return: The two_wheel_park of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._two_wheel_park

    @two_wheel_park.setter
    def two_wheel_park(self, two_wheel_park):
        """
        Sets the two_wheel_park of this PropertyFeaturesDescriptiveEquipments.

        :param two_wheel_park: The two_wheel_park of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._two_wheel_park = two_wheel_park

    @property
    def disabled_access(self):
        """
        Gets the disabled_access of this PropertyFeaturesDescriptiveEquipments.

        :return: The disabled_access of this PropertyFeaturesDescriptiveEquipments.
        :rtype: bool
        """
        return self._disabled_access

    @disabled_access.setter
    def disabled_access(self, disabled_access):
        """
        Sets the disabled_access of this PropertyFeaturesDescriptiveEquipments.

        :param disabled_access: The disabled_access of this PropertyFeaturesDescriptiveEquipments.
        :type: bool
        """

        self._disabled_access = disabled_access

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PropertyFeaturesDescriptiveEquipments):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PropertyBuilding(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'floor_count': 'int',
        'construction_year': 'int',
        'construction_materials': 'str',
        'general_state': 'State',
        'common_area_state': 'State',
        'facade_state': 'State',
        'elevator': 'bool',
        'caretaker': 'bool',
        'digicode': 'bool',
        'intercom': 'bool',
        'adsl': 'bool',
        'cable': 'bool',
        'fiber': 'bool',
        'disable_access': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'floor_count': 'floorCount',
        'construction_year': 'constructionYear',
        'construction_materials': 'constructionMaterials',
        'general_state': 'generalState',
        'common_area_state': 'commonAreaState',
        'facade_state': 'facadeState',
        'elevator': 'elevator',
        'caretaker': 'caretaker',
        'digicode': 'digicode',
        'intercom': 'intercom',
        'adsl': 'adsl',
        'cable': 'cable',
        'fiber': 'fiber',
        'disable_access': 'disableAccess'
    }

    def __init__(self, type=None, floor_count=None, construction_year=None, construction_materials=None, general_state=None, common_area_state=None, facade_state=None, elevator=None, caretaker=None, digicode=None, intercom=None, adsl=None, cable=None, fiber=None, disable_access=None):
        """
        PropertyBuilding - a model defined in Swagger
        """

        self._type = None
        self._floor_count = None
        self._construction_year = None
        self._construction_materials = None
        self._general_state = None
        self._common_area_state = None
        self._facade_state = None
        self._elevator = None
        self._caretaker = None
        self._digicode = None
        self._intercom = None
        self._adsl = None
        self._cable = None
        self._fiber = None
        self._disable_access = None

        if type is not None:
          self.type = type
        if floor_count is not None:
          self.floor_count = floor_count
        if construction_year is not None:
          self.construction_year = construction_year
        if construction_materials is not None:
          self.construction_materials = construction_materials
        if general_state is not None:
          self.general_state = general_state
        if common_area_state is not None:
          self.common_area_state = common_area_state
        if facade_state is not None:
          self.facade_state = facade_state
        if elevator is not None:
          self.elevator = elevator
        if caretaker is not None:
          self.caretaker = caretaker
        if digicode is not None:
          self.digicode = digicode
        if intercom is not None:
          self.intercom = intercom
        if adsl is not None:
          self.adsl = adsl
        if cable is not None:
          self.cable = cable
        if fiber is not None:
          self.fiber = fiber
        if disable_access is not None:
          self.disable_access = disable_access

    @property
    def type(self):
        """
        Gets the type of this PropertyBuilding.

        :return: The type of this PropertyBuilding.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this PropertyBuilding.

        :param type: The type of this PropertyBuilding.
        :type: str
        """
        if type is not None and len(type) > 200:
            raise ValueError("Invalid value for `type`, length must be less than or equal to `200`")

        self._type = type

    @property
    def floor_count(self):
        """
        Gets the floor_count of this PropertyBuilding.

        :return: The floor_count of this PropertyBuilding.
        :rtype: int
        """
        return self._floor_count

    @floor_count.setter
    def floor_count(self, floor_count):
        """
        Sets the floor_count of this PropertyBuilding.

        :param floor_count: The floor_count of this PropertyBuilding.
        :type: int
        """
        if floor_count is not None and floor_count > 100:
            raise ValueError("Invalid value for `floor_count`, must be a value less than or equal to `100`")
        if floor_count is not None and floor_count < 0:
            raise ValueError("Invalid value for `floor_count`, must be a value greater than or equal to `0`")

        self._floor_count = floor_count

    @property
    def construction_year(self):
        """
        Gets the construction_year of this PropertyBuilding.

        :return: The construction_year of this PropertyBuilding.
        :rtype: int
        """
        return self._construction_year

    @construction_year.setter
    def construction_year(self, construction_year):
        """
        Sets the construction_year of this PropertyBuilding.

        :param construction_year: The construction_year of this PropertyBuilding.
        :type: int
        """
        if construction_year is not None and construction_year > 3000:
            raise ValueError("Invalid value for `construction_year`, must be a value less than or equal to `3000`")
        if construction_year is not None and construction_year < 1000:
            raise ValueError("Invalid value for `construction_year`, must be a value greater than or equal to `1000`")

        self._construction_year = construction_year

    @property
    def construction_materials(self):
        """
        Gets the construction_materials of this PropertyBuilding.

        :return: The construction_materials of this PropertyBuilding.
        :rtype: str
        """
        return self._construction_materials

    @construction_materials.setter
    def construction_materials(self, construction_materials):
        """
        Sets the construction_materials of this PropertyBuilding.

        :param construction_materials: The construction_materials of this PropertyBuilding.
        :type: str
        """
        if construction_materials is not None and len(construction_materials) > 1000:
            raise ValueError("Invalid value for `construction_materials`, length must be less than or equal to `1000`")

        self._construction_materials = construction_materials

    @property
    def general_state(self):
        """
        Gets the general_state of this PropertyBuilding.

        :return: The general_state of this PropertyBuilding.
        :rtype: State
        """
        return self._general_state

    @general_state.setter
    def general_state(self, general_state):
        """
        Sets the general_state of this PropertyBuilding.

        :param general_state: The general_state of this PropertyBuilding.
        :type: State
        """

        self._general_state = general_state

    @property
    def common_area_state(self):
        """
        Gets the common_area_state of this PropertyBuilding.

        :return: The common_area_state of this PropertyBuilding.
        :rtype: State
        """
        return self._common_area_state

    @common_area_state.setter
    def common_area_state(self, common_area_state):
        """
        Sets the common_area_state of this PropertyBuilding.

        :param common_area_state: The common_area_state of this PropertyBuilding.
        :type: State
        """

        self._common_area_state = common_area_state

    @property
    def facade_state(self):
        """
        Gets the facade_state of this PropertyBuilding.

        :return: The facade_state of this PropertyBuilding.
        :rtype: State
        """
        return self._facade_state

    @facade_state.setter
    def facade_state(self, facade_state):
        """
        Sets the facade_state of this PropertyBuilding.

        :param facade_state: The facade_state of this PropertyBuilding.
        :type: State
        """

        self._facade_state = facade_state

    @property
    def elevator(self):
        """
        Gets the elevator of this PropertyBuilding.

        :return: The elevator of this PropertyBuilding.
        :rtype: bool
        """
        return self._elevator

    @elevator.setter
    def elevator(self, elevator):
        """
        Sets the elevator of this PropertyBuilding.

        :param elevator: The elevator of this PropertyBuilding.
        :type: bool
        """

        self._elevator = elevator

    @property
    def caretaker(self):
        """
        Gets the caretaker of this PropertyBuilding.

        :return: The caretaker of this PropertyBuilding.
        :rtype: bool
        """
        return self._caretaker

    @caretaker.setter
    def caretaker(self, caretaker):
        """
        Sets the caretaker of this PropertyBuilding.

        :param caretaker: The caretaker of this PropertyBuilding.
        :type: bool
        """

        self._caretaker = caretaker

    @property
    def digicode(self):
        """
        Gets the digicode of this PropertyBuilding.

        :return: The digicode of this PropertyBuilding.
        :rtype: bool
        """
        return self._digicode

    @digicode.setter
    def digicode(self, digicode):
        """
        Sets the digicode of this PropertyBuilding.

        :param digicode: The digicode of this PropertyBuilding.
        :type: bool
        """

        self._digicode = digicode

    @property
    def intercom(self):
        """
        Gets the intercom of this PropertyBuilding.

        :return: The intercom of this PropertyBuilding.
        :rtype: bool
        """
        return self._intercom

    @intercom.setter
    def intercom(self, intercom):
        """
        Sets the intercom of this PropertyBuilding.

        :param intercom: The intercom of this PropertyBuilding.
        :type: bool
        """

        self._intercom = intercom

    @property
    def adsl(self):
        """
        Gets the adsl of this PropertyBuilding.

        :return: The adsl of this PropertyBuilding.
        :rtype: bool
        """
        return self._adsl

    @adsl.setter
    def adsl(self, adsl):
        """
        Sets the adsl of this PropertyBuilding.

        :param adsl: The adsl of this PropertyBuilding.
        :type: bool
        """

        self._adsl = adsl

    @property
    def cable(self):
        """
        Gets the cable of this PropertyBuilding.

        :return: The cable of this PropertyBuilding.
        :rtype: bool
        """
        return self._cable

    @cable.setter
    def cable(self, cable):
        """
        Sets the cable of this PropertyBuilding.

        :param cable: The cable of this PropertyBuilding.
        :type: bool
        """

        self._cable = cable

    @property
    def fiber(self):
        """
        Gets the fiber of this PropertyBuilding.

        :return: The fiber of this PropertyBuilding.
        :rtype: bool
        """
        return self._fiber

    @fiber.setter
    def fiber(self, fiber):
        """
        Sets the fiber of this PropertyBuilding.

        :param fiber: The fiber of this PropertyBuilding.
        :type: bool
        """

        self._fiber = fiber

    @property
    def disable_access(self):
        """
        Gets the disable_access of this PropertyBuilding.

        :return: The disable_access of this PropertyBuilding.
        :rtype: bool
        """
        return self._disable_access

    @disable_access.setter
    def disable_access(self, disable_access):
        """
        Sets the disable_access of this PropertyBuilding.

        :param disable_access: The disable_access of this PropertyBuilding.
        :type: bool
        """

        self._disable_access = disable_access

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PropertyBuilding):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class SectionsMarketStats(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'property_search_query': 'PropertySearchQuery',
        'price_percentiles': 'Percentiles',
        'price_m2_percentiles': 'Percentiles',
        'duration_percentiles': 'Percentiles',
        'price_m2_distribution': 'Histogram',
        'duration_distribution': 'Histogram',
        'price_m2_evolution': 'DateHistogram',
        'duration_evolution': 'DateHistogram'
    }

    attribute_map = {
        'property_search_query': 'propertySearchQuery',
        'price_percentiles': 'pricePercentiles',
        'price_m2_percentiles': 'priceM2Percentiles',
        'duration_percentiles': 'durationPercentiles',
        'price_m2_distribution': 'priceM2Distribution',
        'duration_distribution': 'durationDistribution',
        'price_m2_evolution': 'priceM2Evolution',
        'duration_evolution': 'durationEvolution'
    }

    def __init__(self, property_search_query=None, price_percentiles=None, price_m2_percentiles=None, duration_percentiles=None, price_m2_distribution=None, duration_distribution=None, price_m2_evolution=None, duration_evolution=None):
        """
        SectionsMarketStats - a model defined in Swagger
        """

        self._property_search_query = None
        self._price_percentiles = None
        self._price_m2_percentiles = None
        self._duration_percentiles = None
        self._price_m2_distribution = None
        self._duration_distribution = None
        self._price_m2_evolution = None
        self._duration_evolution = None

        if property_search_query is not None:
          self.property_search_query = property_search_query
        if price_percentiles is not None:
          self.price_percentiles = price_percentiles
        if price_m2_percentiles is not None:
          self.price_m2_percentiles = price_m2_percentiles
        if duration_percentiles is not None:
          self.duration_percentiles = duration_percentiles
        if price_m2_distribution is not None:
          self.price_m2_distribution = price_m2_distribution
        if duration_distribution is not None:
          self.duration_distribution = duration_distribution
        if price_m2_evolution is not None:
          self.price_m2_evolution = price_m2_evolution
        if duration_evolution is not None:
          self.duration_evolution = duration_evolution

    @property
    def property_search_query(self):
        """
        Gets the property_search_query of this SectionsMarketStats.

        :return: The property_search_query of this SectionsMarketStats.
        :rtype: PropertySearchQuery
        """
        return self._property_search_query

    @property_search_query.setter
    def property_search_query(self, property_search_query):
        """
        Sets the property_search_query of this SectionsMarketStats.

        :param property_search_query: The property_search_query of this SectionsMarketStats.
        :type: PropertySearchQuery
        """

        self._property_search_query = property_search_query

    @property
    def price_percentiles(self):
        """
        Gets the price_percentiles of this SectionsMarketStats.

        :return: The price_percentiles of this SectionsMarketStats.
        :rtype: Percentiles
        """
        return self._price_percentiles

    @price_percentiles.setter
    def price_percentiles(self, price_percentiles):
        """
        Sets the price_percentiles of this SectionsMarketStats.

        :param price_percentiles: The price_percentiles of this SectionsMarketStats.
        :type: Percentiles
        """

        self._price_percentiles = price_percentiles

    @property
    def price_m2_percentiles(self):
        """
        Gets the price_m2_percentiles of this SectionsMarketStats.

        :return: The price_m2_percentiles of this SectionsMarketStats.
        :rtype: Percentiles
        """
        return self._price_m2_percentiles

    @price_m2_percentiles.setter
    def price_m2_percentiles(self, price_m2_percentiles):
        """
        Sets the price_m2_percentiles of this SectionsMarketStats.

        :param price_m2_percentiles: The price_m2_percentiles of this SectionsMarketStats.
        :type: Percentiles
        """

        self._price_m2_percentiles = price_m2_percentiles

    @property
    def duration_percentiles(self):
        """
        Gets the duration_percentiles of this SectionsMarketStats.

        :return: The duration_percentiles of this SectionsMarketStats.
        :rtype: Percentiles
        """
        return self._duration_percentiles

    @duration_percentiles.setter
    def duration_percentiles(self, duration_percentiles):
        """
        Sets the duration_percentiles of this SectionsMarketStats.

        :param duration_percentiles: The duration_percentiles of this SectionsMarketStats.
        :type: Percentiles
        """

        self._duration_percentiles = duration_percentiles

    @property
    def price_m2_distribution(self):
        """
        Gets the price_m2_distribution of this SectionsMarketStats.

        :return: The price_m2_distribution of this SectionsMarketStats.
        :rtype: Histogram
        """
        return self._price_m2_distribution

    @price_m2_distribution.setter
    def price_m2_distribution(self, price_m2_distribution):
        """
        Sets the price_m2_distribution of this SectionsMarketStats.

        :param price_m2_distribution: The price_m2_distribution of this SectionsMarketStats.
        :type: Histogram
        """

        self._price_m2_distribution = price_m2_distribution

    @property
    def duration_distribution(self):
        """
        Gets the duration_distribution of this SectionsMarketStats.

        :return: The duration_distribution of this SectionsMarketStats.
        :rtype: Histogram
        """
        return self._duration_distribution

    @duration_distribution.setter
    def duration_distribution(self, duration_distribution):
        """
        Sets the duration_distribution of this SectionsMarketStats.

        :param duration_distribution: The duration_distribution of this SectionsMarketStats.
        :type: Histogram
        """

        self._duration_distribution = duration_distribution

    @property
    def price_m2_evolution(self):
        """
        Gets the price_m2_evolution of this SectionsMarketStats.

        :return: The price_m2_evolution of this SectionsMarketStats.
        :rtype: DateHistogram
        """
        return self._price_m2_evolution

    @price_m2_evolution.setter
    def price_m2_evolution(self, price_m2_evolution):
        """
        Sets the price_m2_evolution of this SectionsMarketStats.

        :param price_m2_evolution: The price_m2_evolution of this SectionsMarketStats.
        :type: DateHistogram
        """

        self._price_m2_evolution = price_m2_evolution

    @property
    def duration_evolution(self):
        """
        Gets the duration_evolution of this SectionsMarketStats.

        :return: The duration_evolution of this SectionsMarketStats.
        :rtype: DateHistogram
        """
        return self._duration_evolution

    @duration_evolution.setter
    def duration_evolution(self, duration_evolution):
        """
        Sets the duration_evolution of this SectionsMarketStats.

        :param duration_evolution: The duration_evolution of this SectionsMarketStats.
        :type: DateHistogram
        """

        self._duration_evolution = duration_evolution

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SectionsMarketStats):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Room(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'room_type': 'str',
        'surface': 'int',
        'wall_covering': 'str',
        'floor_covering': 'str',
        'general_state': 'State'
    }

    attribute_map = {
        'room_type': 'roomType',
        'surface': 'surface',
        'wall_covering': 'wallCovering',
        'floor_covering': 'floorCovering',
        'general_state': 'generalState'
    }

    def __init__(self, room_type=None, surface=None, wall_covering=None, floor_covering=None, general_state=None):
        """
        Room - a model defined in Swagger
        """

        self._room_type = None
        self._surface = None
        self._wall_covering = None
        self._floor_covering = None
        self._general_state = None

        if room_type is not None:
          self.room_type = room_type
        if surface is not None:
          self.surface = surface
        if wall_covering is not None:
          self.wall_covering = wall_covering
        if floor_covering is not None:
          self.floor_covering = floor_covering
        if general_state is not None:
          self.general_state = general_state

    @property
    def room_type(self):
        """
        Gets the room_type of this Room.

        :return: The room_type of this Room.
        :rtype: str
        """
        return self._room_type

    @room_type.setter
    def room_type(self, room_type):
        """
        Sets the room_type of this Room.

        :param room_type: The room_type of this Room.
        :type: str
        """
        if room_type is not None and len(room_type) > 200:
            raise ValueError("Invalid value for `room_type`, length must be less than or equal to `200`")

        self._room_type = room_type

    @property
    def surface(self):
        """
        Gets the surface of this Room.

        :return: The surface of this Room.
        :rtype: int
        """
        return self._surface

    @surface.setter
    def surface(self, surface):
        """
        Sets the surface of this Room.

        :param surface: The surface of this Room.
        :type: int
        """
        if surface is not None and surface > 1000:
            raise ValueError("Invalid value for `surface`, must be a value less than or equal to `1000`")
        if surface is not None and surface < 0:
            raise ValueError("Invalid value for `surface`, must be a value greater than or equal to `0`")

        self._surface = surface

    @property
    def wall_covering(self):
        """
        Gets the wall_covering of this Room.

        :return: The wall_covering of this Room.
        :rtype: str
        """
        return self._wall_covering

    @wall_covering.setter
    def wall_covering(self, wall_covering):
        """
        Sets the wall_covering of this Room.

        :param wall_covering: The wall_covering of this Room.
        :type: str
        """
        if wall_covering is not None and len(wall_covering) > 200:
            raise ValueError("Invalid value for `wall_covering`, length must be less than or equal to `200`")

        self._wall_covering = wall_covering

    @property
    def floor_covering(self):
        """
        Gets the floor_covering of this Room.

        :return: The floor_covering of this Room.
        :rtype: str
        """
        return self._floor_covering

    @floor_covering.setter
    def floor_covering(self, floor_covering):
        """
        Sets the floor_covering of this Room.

        :param floor_covering: The floor_covering of this Room.
        :type: str
        """
        if floor_covering is not None and len(floor_covering) > 200:
            raise ValueError("Invalid value for `floor_covering`, length must be less than or equal to `200`")

        self._floor_covering = floor_covering

    @property
    def general_state(self):
        """
        Gets the general_state of this Room.

        :return: The general_state of this Room.
        :rtype: State
        """
        return self._general_state

    @general_state.setter
    def general_state(self, general_state):
        """
        Sets the general_state of this Room.

        :param general_state: The general_state of this Room.
        :type: State
        """

        self._general_state = general_state

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Room):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PropertyFeaturesDescriptive(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'pros': 'list[str]',
        'cons': 'list[str]',
        'comments': 'str',
        'general_state': 'State',
        'services': 'PropertyFeaturesDescriptiveServices',
        'equipments': 'PropertyFeaturesDescriptiveEquipments'
    }

    attribute_map = {
        'description': 'description',
        'pros': 'pros',
        'cons': 'cons',
        'comments': 'comments',
        'general_state': 'generalState',
        'services': 'services',
        'equipments': 'equipments'
    }

    def __init__(self, description=None, pros=None, cons=None, comments=None, general_state=None, services=None, equipments=None):
        """
        PropertyFeaturesDescriptive - a model defined in Swagger
        """

        self._description = None
        self._pros = None
        self._cons = None
        self._comments = None
        self._general_state = None
        self._services = None
        self._equipments = None

        if description is not None:
          self.description = description
        if pros is not None:
          self.pros = pros
        if cons is not None:
          self.cons = cons
        if comments is not None:
          self.comments = comments
        if general_state is not None:
          self.general_state = general_state
        if services is not None:
          self.services = services
        if equipments is not None:
          self.equipments = equipments

    @property
    def description(self):
        """
        Gets the description of this PropertyFeaturesDescriptive.

        :return: The description of this PropertyFeaturesDescriptive.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this PropertyFeaturesDescriptive.

        :param description: The description of this PropertyFeaturesDescriptive.
        :type: str
        """
        if description is not None and len(description) > 10000:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `10000`")

        self._description = description

    @property
    def pros(self):
        """
        Gets the pros of this PropertyFeaturesDescriptive.

        :return: The pros of this PropertyFeaturesDescriptive.
        :rtype: list[str]
        """
        return self._pros

    @pros.setter
    def pros(self, pros):
        """
        Sets the pros of this PropertyFeaturesDescriptive.

        :param pros: The pros of this PropertyFeaturesDescriptive.
        :type: list[str]
        """

        self._pros = pros

    @property
    def cons(self):
        """
        Gets the cons of this PropertyFeaturesDescriptive.

        :return: The cons of this PropertyFeaturesDescriptive.
        :rtype: list[str]
        """
        return self._cons

    @cons.setter
    def cons(self, cons):
        """
        Sets the cons of this PropertyFeaturesDescriptive.

        :param cons: The cons of this PropertyFeaturesDescriptive.
        :type: list[str]
        """

        self._cons = cons

    @property
    def comments(self):
        """
        Gets the comments of this PropertyFeaturesDescriptive.

        :return: The comments of this PropertyFeaturesDescriptive.
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """
        Sets the comments of this PropertyFeaturesDescriptive.

        :param comments: The comments of this PropertyFeaturesDescriptive.
        :type: str
        """
        if comments is not None and len(comments) > 2000:
            raise ValueError("Invalid value for `comments`, length must be less than or equal to `2000`")

        self._comments = comments

    @property
    def general_state(self):
        """
        Gets the general_state of this PropertyFeaturesDescriptive.

        :return: The general_state of this PropertyFeaturesDescriptive.
        :rtype: State
        """
        return self._general_state

    @general_state.setter
    def general_state(self, general_state):
        """
        Sets the general_state of this PropertyFeaturesDescriptive.

        :param general_state: The general_state of this PropertyFeaturesDescriptive.
        :type: State
        """

        self._general_state = general_state

    @property
    def services(self):
        """
        Gets the services of this PropertyFeaturesDescriptive.

        :return: The services of this PropertyFeaturesDescriptive.
        :rtype: PropertyFeaturesDescriptiveServices
        """
        return self._services

    @services.setter
    def services(self, services):
        """
        Sets the services of this PropertyFeaturesDescriptive.

        :param services: The services of this PropertyFeaturesDescriptive.
        :type: PropertyFeaturesDescriptiveServices
        """

        self._services = services

    @property
    def equipments(self):
        """
        Gets the equipments of this PropertyFeaturesDescriptive.

        :return: The equipments of this PropertyFeaturesDescriptive.
        :rtype: PropertyFeaturesDescriptiveEquipments
        """
        return self._equipments

    @equipments.setter
    def equipments(self, equipments):
        """
        Sets the equipments of this PropertyFeaturesDescriptive.

        :param equipments: The equipments of this PropertyFeaturesDescriptive.
        :type: PropertyFeaturesDescriptiveEquipments
        """

        self._equipments = equipments

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PropertyFeaturesDescriptive):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class AnnoncesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def ads_get(self, **kwargs):
        """
        Rechercher des annonces
        Recherche sur l'ensemble des annonces publiées par les portails selon certains critères comme la date de publication, le prix, la surface... _(voir ci-dessous pour une liste exhaustive)_.  La recherche plein-texte est disponible sur le titre et la description via le query param `q` _(voir notre [FAQ](https://yanporthelp.zendesk.com/hc/fr/articles/208456909-Comment-affiner-ma-recherche-avec-des-mots-cl%C3%A9s-) concernant la syntaxe)_  Par défaut les résultats sont paginés, pour parcourir l'ensemble des annonces les paramètres `from` et `size` doivent être renseignés. Le paramètre `from` définit le début du set de données et `size` le nombre d'éléments à récupérer. Le nombre `total` d'éléments est renvoyé dans la réponse.  Concernant le tri le paramètre `sort` à pour syntaxe `field:asc|desc` en remplaçant `field` par le nom du champ sur lequel appliqué le tri.  # Exemples   ## Les annonces en cours de publication sur Levallois-Perret entre 120 et 130m²     /ads?active=true&zipCodes=92300&surfaceMin=120&surfaceMax=130   ## Les annonces en cours de publication dans le 17ème arrondissement de Paris avec balcon     /ads?active=true&zipCodes=75017&q=balcon   ## Les dernières annonces de particulier publiées en Corse sur LeBonCoin et PAP     /ads?active=true&crawlSources=LE_BON_COIN&crawlSources=PAP&departments=2B&sort=property.marketing.publicationDate:asc 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.ads_get(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int _from: Début de la pagination
        :param int size: Nombre de résultats
        :param str sort: Trier par
        :param str q: Recherche plein-texte
        :param list[str] marketing_types: Types de marché (vente, location, vente en viager)
        :param list[str] crawl_sources: Portails immobiliers
        :param bool active: Statut de l'annonce (expirée ou pas)
        :param list[str] dealer_types: Types de vendeur (agence, mandataire..)
        :param list[str] dealer_names: Liste de noms de vendeurs
        :param list[int] dealer_ids: Liste d'identifiants de vendeurs
        :param list[str] property_ids: Liste d'identifiants de biens
        :param list[str] property_types: Types de bien
        :param list[int] room_counts: Nombre de pièces
        :param list[str] departments: Liste de départements
        :param list[str] zip_codes: Liste de codes postaux
        :param list[int] city_ids: Liste d'identifiants de villes
        :param datetime publication_date_min: Date minimale de publication (YYYY-mm-ddTHH:mm:ss)
        :param datetime publication_date_max: Date limite de publication (YYYY-mm-ddTHH:mm:ss)
        :param datetime delete_date_min: Date minimale de suppression (YYYY-mm-ddTHH:mm:ss)
        :param datetime delete_date_max: Date limite de suppression (YYYY-mm-ddTHH:mm:ss)
        :param int duration_days_min: Durée minimale en jours
        :param int duration_days_max: Durée maximale en jours
        :param int surface_min: Surface minimale
        :param int surface_max: Surface maximale
        :param int price_min: Prix minimum
        :param int price_max: Prix maximum
        :param list[str] missing_fields: Attributs manquants
        :param list[str] existing_fields: Attributs existants
        :param list[str] excluded_ids: Identifiants à exclure
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.ads_get_with_http_info(**kwargs)
        else:
            (data) = self.ads_get_with_http_info(**kwargs)
            return data

    def ads_get_with_http_info(self, **kwargs):
        """
        Rechercher des annonces
        Recherche sur l'ensemble des annonces publiées par les portails selon certains critères comme la date de publication, le prix, la surface... _(voir ci-dessous pour une liste exhaustive)_.  La recherche plein-texte est disponible sur le titre et la description via le query param `q` _(voir notre [FAQ](https://yanporthelp.zendesk.com/hc/fr/articles/208456909-Comment-affiner-ma-recherche-avec-des-mots-cl%C3%A9s-) concernant la syntaxe)_  Par défaut les résultats sont paginés, pour parcourir l'ensemble des annonces les paramètres `from` et `size` doivent être renseignés. Le paramètre `from` définit le début du set de données et `size` le nombre d'éléments à récupérer. Le nombre `total` d'éléments est renvoyé dans la réponse.  Concernant le tri le paramètre `sort` à pour syntaxe `field:asc|desc` en remplaçant `field` par le nom du champ sur lequel appliqué le tri.  # Exemples   ## Les annonces en cours de publication sur Levallois-Perret entre 120 et 130m²     /ads?active=true&zipCodes=92300&surfaceMin=120&surfaceMax=130   ## Les annonces en cours de publication dans le 17ème arrondissement de Paris avec balcon     /ads?active=true&zipCodes=75017&q=balcon   ## Les dernières annonces de particulier publiées en Corse sur LeBonCoin et PAP     /ads?active=true&crawlSources=LE_BON_COIN&crawlSources=PAP&departments=2B&sort=property.marketing.publicationDate:asc 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.ads_get_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int _from: Début de la pagination
        :param int size: Nombre de résultats
        :param str sort: Trier par
        :param str q: Recherche plein-texte
        :param list[str] marketing_types: Types de marché (vente, location, vente en viager)
        :param list[str] crawl_sources: Portails immobiliers
        :param bool active: Statut de l'annonce (expirée ou pas)
        :param list[str] dealer_types: Types de vendeur (agence, mandataire..)
        :param list[str] dealer_names: Liste de noms de vendeurs
        :param list[int] dealer_ids: Liste d'identifiants de vendeurs
        :param list[str] property_ids: Liste d'identifiants de biens
        :param list[str] property_types: Types de bien
        :param list[int] room_counts: Nombre de pièces
        :param list[str] departments: Liste de départements
        :param list[str] zip_codes: Liste de codes postaux
        :param list[int] city_ids: Liste d'identifiants de villes
        :param datetime publication_date_min: Date minimale de publication (YYYY-mm-ddTHH:mm:ss)
        :param datetime publication_date_max: Date limite de publication (YYYY-mm-ddTHH:mm:ss)
        :param datetime delete_date_min: Date minimale de suppression (YYYY-mm-ddTHH:mm:ss)
        :param datetime delete_date_max: Date limite de suppression (YYYY-mm-ddTHH:mm:ss)
        :param int duration_days_min: Durée minimale en jours
        :param int duration_days_max: Durée maximale en jours
        :param int surface_min: Surface minimale
        :param int surface_max: Surface maximale
        :param int price_min: Prix minimum
        :param int price_max: Prix maximum
        :param list[str] missing_fields: Attributs manquants
        :param list[str] existing_fields: Attributs existants
        :param list[str] excluded_ids: Identifiants à exclure
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'size', 'sort', 'q', 'marketing_types', 'crawl_sources', 'active', 'dealer_types', 'dealer_names', 'dealer_ids', 'property_ids', 'property_types', 'room_counts', 'departments', 'zip_codes', 'city_ids', 'publication_date_min', 'publication_date_max', 'delete_date_min', 'delete_date_max', 'duration_days_min', 'duration_days_max', 'surface_min', 'surface_max', 'price_min', 'price_max', 'missing_fields', 'existing_fields', 'excluded_ids']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ads_get" % key
                )
            params[key] = val
        del params['kwargs']

        if '_from' in params and params['_from'] < 0:
            raise ValueError("Invalid value for parameter `_from` when calling `ads_get`, must be a value greater than or equal to `0`")
        if 'size' in params and params['size'] > 1000:
            raise ValueError("Invalid value for parameter `size` when calling `ads_get`, must be a value less than or equal to `1000`")
        if 'size' in params and params['size'] < 0:
            raise ValueError("Invalid value for parameter `size` when calling `ads_get`, must be a value greater than or equal to `0`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))
        if 'size' in params:
            query_params.append(('size', params['size']))
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'q' in params:
            query_params.append(('q', params['q']))
        if 'marketing_types' in params:
            query_params.append(('marketingTypes', params['marketing_types']))
            collection_formats['marketingTypes'] = 'multi'
        if 'crawl_sources' in params:
            query_params.append(('crawlSources', params['crawl_sources']))
            collection_formats['crawlSources'] = 'multi'
        if 'active' in params:
            query_params.append(('active', params['active']))
        if 'dealer_types' in params:
            query_params.append(('dealerTypes', params['dealer_types']))
            collection_formats['dealerTypes'] = 'multi'
        if 'dealer_names' in params:
            query_params.append(('dealerNames', params['dealer_names']))
            collection_formats['dealerNames'] = 'multi'
        if 'dealer_ids' in params:
            query_params.append(('dealerIds', params['dealer_ids']))
            collection_formats['dealerIds'] = 'multi'
        if 'property_ids' in params:
            query_params.append(('propertyIds', params['property_ids']))
            collection_formats['propertyIds'] = 'multi'
        if 'property_types' in params:
            query_params.append(('propertyTypes', params['property_types']))
            collection_formats['propertyTypes'] = 'multi'
        if 'room_counts' in params:
            query_params.append(('roomCounts', params['room_counts']))
            collection_formats['roomCounts'] = 'multi'
        if 'departments' in params:
            query_params.append(('departments', params['departments']))
            collection_formats['departments'] = 'multi'
        if 'zip_codes' in params:
            query_params.append(('zipCodes', params['zip_codes']))
            collection_formats['zipCodes'] = 'multi'
        if 'city_ids' in params:
            query_params.append(('cityIds', params['city_ids']))
            collection_formats['cityIds'] = 'multi'
        if 'publication_date_min' in params:
            query_params.append(('publicationDateMin', params['publication_date_min']))
        if 'publication_date_max' in params:
            query_params.append(('publicationDateMax', params['publication_date_max']))
        if 'delete_date_min' in params:
            query_params.append(('deleteDateMin', params['delete_date_min']))
        if 'delete_date_max' in params:
            query_params.append(('deleteDateMax', params['delete_date_max']))
        if 'duration_days_min' in params:
            query_params.append(('durationDaysMin', params['duration_days_min']))
        if 'duration_days_max' in params:
            query_params.append(('durationDaysMax', params['duration_days_max']))
        if 'surface_min' in params:
            query_params.append(('surfaceMin', params['surface_min']))
        if 'surface_max' in params:
            query_params.append(('surfaceMax', params['surface_max']))
        if 'price_min' in params:
            query_params.append(('priceMin', params['price_min']))
        if 'price_max' in params:
            query_params.append(('priceMax', params['price_max']))
        if 'missing_fields' in params:
            query_params.append(('missingFields', params['missing_fields']))
            collection_formats['missingFields'] = 'csv'
        if 'existing_fields' in params:
            query_params.append(('existingFields', params['existing_fields']))
            collection_formats['existingFields'] = 'csv'
        if 'excluded_ids' in params:
            query_params.append(('excludedIds', params['excluded_ids']))
            collection_formats['excludedIds'] = 'csv'

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/ads', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse200',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def ads_id_get(self, id, **kwargs):
        """
        Récupérer une annonce (ID)
        Récupérer une annonce par son identifiant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.ads_id_get(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: L'identifiant de l'annonce (required)
        :return: Ad
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.ads_id_get_with_http_info(id, **kwargs)
        else:
            (data) = self.ads_id_get_with_http_info(id, **kwargs)
            return data

    def ads_id_get_with_http_info(self, id, **kwargs):
        """
        Récupérer une annonce (ID)
        Récupérer une annonce par son identifiant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.ads_id_get_with_http_info(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: L'identifiant de l'annonce (required)
        :return: Ad
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ads_id_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `ads_id_get`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/ads/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Ad',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def ads_ids_get(self, ids, **kwargs):
        """
        Récupérer des annonces (ID)
        Récupérer des annonces par leurs identifiants
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.ads_ids_get(ids, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] ids: Les identifiants des annonces (required)
        :return: list[Ad]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.ads_ids_get_with_http_info(ids, **kwargs)
        else:
            (data) = self.ads_ids_get_with_http_info(ids, **kwargs)
            return data

    def ads_ids_get_with_http_info(self, ids, **kwargs):
        """
        Récupérer des annonces (ID)
        Récupérer des annonces par leurs identifiants
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.ads_ids_get_with_http_info(ids, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] ids: Les identifiants des annonces (required)
        :return: list[Ad]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ids']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ads_ids_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ids' is set
        if ('ids' not in params) or (params['ids'] is None):
            raise ValueError("Missing the required parameter `ids` when calling `ads_ids_get`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ids' in params:
            query_params.append(('ids', params['ids']))
            collection_formats['ids'] = 'multi'

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/ads/ids', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[Ad]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def ads_urls_get(self, url, **kwargs):
        """
        Récupérer une annonce (URL)
        Récupérer une annonce par son url
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.ads_urls_get(url, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str url: Url de l'annonce (required)
        :return: Ad
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.ads_urls_get_with_http_info(url, **kwargs)
        else:
            (data) = self.ads_urls_get_with_http_info(url, **kwargs)
            return data

    def ads_urls_get_with_http_info(self, url, **kwargs):
        """
        Récupérer une annonce (URL)
        Récupérer une annonce par son url
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.ads_urls_get_with_http_info(url, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str url: Url de l'annonce (required)
        :return: Ad
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['url']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ads_urls_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'url' is set
        if ('url' not in params) or (params['url'] is None):
            raise ValueError("Missing the required parameter `url` when calling `ads_urls_get`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'url' in params:
            query_params.append(('url', params['url']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/ads/urls', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Ad',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class SectionsPropertyPriceStudy(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'price_comment': 'str',
        'similar_properties_comment': 'str',
        'similar_properties': 'list[ModelProperty]',
        'show_market_price': 'bool',
        'estimated_price': 'float',
        'active_serie': 'bool',
        'expired_serie': 'bool'
    }

    attribute_map = {
        'price_comment': 'priceComment',
        'similar_properties_comment': 'similarPropertiesComment',
        'similar_properties': 'similarProperties',
        'show_market_price': 'showMarketPrice',
        'estimated_price': 'estimatedPrice',
        'active_serie': 'activeSerie',
        'expired_serie': 'expiredSerie'
    }

    def __init__(self, price_comment=None, similar_properties_comment=None, similar_properties=None, show_market_price=None, estimated_price=None, active_serie=None, expired_serie=None):
        """
        SectionsPropertyPriceStudy - a model defined in Swagger
        """

        self._price_comment = None
        self._similar_properties_comment = None
        self._similar_properties = None
        self._show_market_price = None
        self._estimated_price = None
        self._active_serie = None
        self._expired_serie = None

        if price_comment is not None:
          self.price_comment = price_comment
        if similar_properties_comment is not None:
          self.similar_properties_comment = similar_properties_comment
        if similar_properties is not None:
          self.similar_properties = similar_properties
        if show_market_price is not None:
          self.show_market_price = show_market_price
        if estimated_price is not None:
          self.estimated_price = estimated_price
        if active_serie is not None:
          self.active_serie = active_serie
        if expired_serie is not None:
          self.expired_serie = expired_serie

    @property
    def price_comment(self):
        """
        Gets the price_comment of this SectionsPropertyPriceStudy.

        :return: The price_comment of this SectionsPropertyPriceStudy.
        :rtype: str
        """
        return self._price_comment

    @price_comment.setter
    def price_comment(self, price_comment):
        """
        Sets the price_comment of this SectionsPropertyPriceStudy.

        :param price_comment: The price_comment of this SectionsPropertyPriceStudy.
        :type: str
        """

        self._price_comment = price_comment

    @property
    def similar_properties_comment(self):
        """
        Gets the similar_properties_comment of this SectionsPropertyPriceStudy.

        :return: The similar_properties_comment of this SectionsPropertyPriceStudy.
        :rtype: str
        """
        return self._similar_properties_comment

    @similar_properties_comment.setter
    def similar_properties_comment(self, similar_properties_comment):
        """
        Sets the similar_properties_comment of this SectionsPropertyPriceStudy.

        :param similar_properties_comment: The similar_properties_comment of this SectionsPropertyPriceStudy.
        :type: str
        """

        self._similar_properties_comment = similar_properties_comment

    @property
    def similar_properties(self):
        """
        Gets the similar_properties of this SectionsPropertyPriceStudy.

        :return: The similar_properties of this SectionsPropertyPriceStudy.
        :rtype: list[ModelProperty]
        """
        return self._similar_properties

    @similar_properties.setter
    def similar_properties(self, similar_properties):
        """
        Sets the similar_properties of this SectionsPropertyPriceStudy.

        :param similar_properties: The similar_properties of this SectionsPropertyPriceStudy.
        :type: list[ModelProperty]
        """

        self._similar_properties = similar_properties

    @property
    def show_market_price(self):
        """
        Gets the show_market_price of this SectionsPropertyPriceStudy.

        :return: The show_market_price of this SectionsPropertyPriceStudy.
        :rtype: bool
        """
        return self._show_market_price

    @show_market_price.setter
    def show_market_price(self, show_market_price):
        """
        Sets the show_market_price of this SectionsPropertyPriceStudy.

        :param show_market_price: The show_market_price of this SectionsPropertyPriceStudy.
        :type: bool
        """

        self._show_market_price = show_market_price

    @property
    def estimated_price(self):
        """
        Gets the estimated_price of this SectionsPropertyPriceStudy.

        :return: The estimated_price of this SectionsPropertyPriceStudy.
        :rtype: float
        """
        return self._estimated_price

    @estimated_price.setter
    def estimated_price(self, estimated_price):
        """
        Sets the estimated_price of this SectionsPropertyPriceStudy.

        :param estimated_price: The estimated_price of this SectionsPropertyPriceStudy.
        :type: float
        """

        self._estimated_price = estimated_price

    @property
    def active_serie(self):
        """
        Gets the active_serie of this SectionsPropertyPriceStudy.

        :return: The active_serie of this SectionsPropertyPriceStudy.
        :rtype: bool
        """
        return self._active_serie

    @active_serie.setter
    def active_serie(self, active_serie):
        """
        Sets the active_serie of this SectionsPropertyPriceStudy.

        :param active_serie: The active_serie of this SectionsPropertyPriceStudy.
        :type: bool
        """

        self._active_serie = active_serie

    @property
    def expired_serie(self):
        """
        Gets the expired_serie of this SectionsPropertyPriceStudy.

        :return: The expired_serie of this SectionsPropertyPriceStudy.
        :rtype: bool
        """
        return self._expired_serie

    @expired_serie.setter
    def expired_serie(self, expired_serie):
        """
        Sets the expired_serie of this SectionsPropertyPriceStudy.

        :param expired_serie: The expired_serie of this SectionsPropertyPriceStudy.
        :type: bool
        """

        self._expired_serie = expired_serie

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SectionsPropertyPriceStudy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PropertyFeaturesEnergy(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'heating_types': 'list[str]',
        'heating_mode': 'str',
        'water_heating_types': 'list[str]',
        'water_heating_mode': 'str',
        'consumption': 'int',
        'green_house_gas_consumption': 'int'
    }

    attribute_map = {
        'heating_types': 'heatingTypes',
        'heating_mode': 'heatingMode',
        'water_heating_types': 'waterHeatingTypes',
        'water_heating_mode': 'waterHeatingMode',
        'consumption': 'consumption',
        'green_house_gas_consumption': 'greenHouseGasConsumption'
    }

    def __init__(self, heating_types=None, heating_mode=None, water_heating_types=None, water_heating_mode=None, consumption=None, green_house_gas_consumption=None):
        """
        PropertyFeaturesEnergy - a model defined in Swagger
        """

        self._heating_types = None
        self._heating_mode = None
        self._water_heating_types = None
        self._water_heating_mode = None
        self._consumption = None
        self._green_house_gas_consumption = None

        if heating_types is not None:
          self.heating_types = heating_types
        if heating_mode is not None:
          self.heating_mode = heating_mode
        if water_heating_types is not None:
          self.water_heating_types = water_heating_types
        if water_heating_mode is not None:
          self.water_heating_mode = water_heating_mode
        if consumption is not None:
          self.consumption = consumption
        if green_house_gas_consumption is not None:
          self.green_house_gas_consumption = green_house_gas_consumption

    @property
    def heating_types(self):
        """
        Gets the heating_types of this PropertyFeaturesEnergy.

        :return: The heating_types of this PropertyFeaturesEnergy.
        :rtype: list[str]
        """
        return self._heating_types

    @heating_types.setter
    def heating_types(self, heating_types):
        """
        Sets the heating_types of this PropertyFeaturesEnergy.

        :param heating_types: The heating_types of this PropertyFeaturesEnergy.
        :type: list[str]
        """
        allowed_values = ["ELECTRIC", "GAS", "FUEL", "WOOD", "SOLAR", "HEAT_PUMP", "UNDERFLOOR", "NONE", "OTHER"]
        if not set(heating_types).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `heating_types` [{0}], must be a subset of [{1}]"
                .format(", ".join(map(str, set(heating_types)-set(allowed_values))),
                        ", ".join(map(str, allowed_values)))
            )

        self._heating_types = heating_types

    @property
    def heating_mode(self):
        """
        Gets the heating_mode of this PropertyFeaturesEnergy.

        :return: The heating_mode of this PropertyFeaturesEnergy.
        :rtype: str
        """
        return self._heating_mode

    @heating_mode.setter
    def heating_mode(self, heating_mode):
        """
        Sets the heating_mode of this PropertyFeaturesEnergy.

        :param heating_mode: The heating_mode of this PropertyFeaturesEnergy.
        :type: str
        """
        allowed_values = ["INDIVIDUAL", "COLLECTIVE", "MIXED"]
        if heating_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `heating_mode` ({0}), must be one of {1}"
                .format(heating_mode, allowed_values)
            )

        self._heating_mode = heating_mode

    @property
    def water_heating_types(self):
        """
        Gets the water_heating_types of this PropertyFeaturesEnergy.

        :return: The water_heating_types of this PropertyFeaturesEnergy.
        :rtype: list[str]
        """
        return self._water_heating_types

    @water_heating_types.setter
    def water_heating_types(self, water_heating_types):
        """
        Sets the water_heating_types of this PropertyFeaturesEnergy.

        :param water_heating_types: The water_heating_types of this PropertyFeaturesEnergy.
        :type: list[str]
        """
        allowed_values = ["ELECTRIC", "GAS", "FUEL", "WOOD", "SOLAR", "HEAT_PUMP", "UNDERFLOOR", "NONE", "OTHER"]
        if not set(water_heating_types).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `water_heating_types` [{0}], must be a subset of [{1}]"
                .format(", ".join(map(str, set(water_heating_types)-set(allowed_values))),
                        ", ".join(map(str, allowed_values)))
            )

        self._water_heating_types = water_heating_types

    @property
    def water_heating_mode(self):
        """
        Gets the water_heating_mode of this PropertyFeaturesEnergy.

        :return: The water_heating_mode of this PropertyFeaturesEnergy.
        :rtype: str
        """
        return self._water_heating_mode

    @water_heating_mode.setter
    def water_heating_mode(self, water_heating_mode):
        """
        Sets the water_heating_mode of this PropertyFeaturesEnergy.

        :param water_heating_mode: The water_heating_mode of this PropertyFeaturesEnergy.
        :type: str
        """
        allowed_values = ["INDIVIDUAL", "COLLECTIVE", "MIXED"]
        if water_heating_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `water_heating_mode` ({0}), must be one of {1}"
                .format(water_heating_mode, allowed_values)
            )

        self._water_heating_mode = water_heating_mode

    @property
    def consumption(self):
        """
        Gets the consumption of this PropertyFeaturesEnergy.

        :return: The consumption of this PropertyFeaturesEnergy.
        :rtype: int
        """
        return self._consumption

    @consumption.setter
    def consumption(self, consumption):
        """
        Sets the consumption of this PropertyFeaturesEnergy.

        :param consumption: The consumption of this PropertyFeaturesEnergy.
        :type: int
        """
        if consumption is not None and consumption > 10000:
            raise ValueError("Invalid value for `consumption`, must be a value less than or equal to `10000`")
        if consumption is not None and consumption < 0:
            raise ValueError("Invalid value for `consumption`, must be a value greater than or equal to `0`")

        self._consumption = consumption

    @property
    def green_house_gas_consumption(self):
        """
        Gets the green_house_gas_consumption of this PropertyFeaturesEnergy.

        :return: The green_house_gas_consumption of this PropertyFeaturesEnergy.
        :rtype: int
        """
        return self._green_house_gas_consumption

    @green_house_gas_consumption.setter
    def green_house_gas_consumption(self, green_house_gas_consumption):
        """
        Sets the green_house_gas_consumption of this PropertyFeaturesEnergy.

        :param green_house_gas_consumption: The green_house_gas_consumption of this PropertyFeaturesEnergy.
        :type: int
        """
        if green_house_gas_consumption is not None and green_house_gas_consumption > 10000:
            raise ValueError("Invalid value for `green_house_gas_consumption`, must be a value less than or equal to `10000`")
        if green_house_gas_consumption is not None and green_house_gas_consumption < 0:
            raise ValueError("Invalid value for `green_house_gas_consumption`, must be a value greater than or equal to `0`")

        self._green_house_gas_consumption = green_house_gas_consumption

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PropertyFeaturesEnergy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PropertyMarketing(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'price': 'float',
        'selling_price': 'float',
        'price_events': 'list[PriceEvent]',
        'dealers': 'list[MarketingDealer]',
        'marketing_start_date': 'datetime',
        'marketing_end_date': 'datetime',
        'publication_start_date': 'datetime',
        'publication_end_date': 'datetime',
        'rental_expenses': 'float',
        'rental_expenses_included': 'bool',
        'deposit': 'float',
        'property_tax': 'float',
        'fees': 'float',
        'fees_included': 'bool',
        'exclusive_mandate': 'bool',
        'occupied': 'bool',
        'rent_control': 'RentControl'
    }

    attribute_map = {
        'type': 'type',
        'price': 'price',
        'selling_price': 'sellingPrice',
        'price_events': 'priceEvents',
        'dealers': 'dealers',
        'marketing_start_date': 'marketingStartDate',
        'marketing_end_date': 'marketingEndDate',
        'publication_start_date': 'publicationStartDate',
        'publication_end_date': 'publicationEndDate',
        'rental_expenses': 'rentalExpenses',
        'rental_expenses_included': 'rentalExpensesIncluded',
        'deposit': 'deposit',
        'property_tax': 'propertyTax',
        'fees': 'fees',
        'fees_included': 'feesIncluded',
        'exclusive_mandate': 'exclusiveMandate',
        'occupied': 'occupied',
        'rent_control': 'rentControl'
    }

    def __init__(self, type=None, price=None, selling_price=None, price_events=None, dealers=None, marketing_start_date=None, marketing_end_date=None, publication_start_date=None, publication_end_date=None, rental_expenses=None, rental_expenses_included=None, deposit=None, property_tax=None, fees=None, fees_included=None, exclusive_mandate=None, occupied=None, rent_control=None):
        """
        PropertyMarketing - a model defined in Swagger
        """

        self._type = None
        self._price = None
        self._selling_price = None
        self._price_events = None
        self._dealers = None
        self._marketing_start_date = None
        self._marketing_end_date = None
        self._publication_start_date = None
        self._publication_end_date = None
        self._rental_expenses = None
        self._rental_expenses_included = None
        self._deposit = None
        self._property_tax = None
        self._fees = None
        self._fees_included = None
        self._exclusive_mandate = None
        self._occupied = None
        self._rent_control = None

        if type is not None:
          self.type = type
        if price is not None:
          self.price = price
        if selling_price is not None:
          self.selling_price = selling_price
        if price_events is not None:
          self.price_events = price_events
        if dealers is not None:
          self.dealers = dealers
        if marketing_start_date is not None:
          self.marketing_start_date = marketing_start_date
        if marketing_end_date is not None:
          self.marketing_end_date = marketing_end_date
        if publication_start_date is not None:
          self.publication_start_date = publication_start_date
        if publication_end_date is not None:
          self.publication_end_date = publication_end_date
        if rental_expenses is not None:
          self.rental_expenses = rental_expenses
        if rental_expenses_included is not None:
          self.rental_expenses_included = rental_expenses_included
        if deposit is not None:
          self.deposit = deposit
        if property_tax is not None:
          self.property_tax = property_tax
        if fees is not None:
          self.fees = fees
        if fees_included is not None:
          self.fees_included = fees_included
        if exclusive_mandate is not None:
          self.exclusive_mandate = exclusive_mandate
        if occupied is not None:
          self.occupied = occupied
        if rent_control is not None:
          self.rent_control = rent_control

    @property
    def type(self):
        """
        Gets the type of this PropertyMarketing.

        :return: The type of this PropertyMarketing.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this PropertyMarketing.

        :param type: The type of this PropertyMarketing.
        :type: str
        """
        allowed_values = ["SALE", "RENT", "NEW_BUILD"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def price(self):
        """
        Gets the price of this PropertyMarketing.

        :return: The price of this PropertyMarketing.
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """
        Sets the price of this PropertyMarketing.

        :param price: The price of this PropertyMarketing.
        :type: float
        """

        self._price = price

    @property
    def selling_price(self):
        """
        Gets the selling_price of this PropertyMarketing.

        :return: The selling_price of this PropertyMarketing.
        :rtype: float
        """
        return self._selling_price

    @selling_price.setter
    def selling_price(self, selling_price):
        """
        Sets the selling_price of this PropertyMarketing.

        :param selling_price: The selling_price of this PropertyMarketing.
        :type: float
        """

        self._selling_price = selling_price

    @property
    def price_events(self):
        """
        Gets the price_events of this PropertyMarketing.

        :return: The price_events of this PropertyMarketing.
        :rtype: list[PriceEvent]
        """
        return self._price_events

    @price_events.setter
    def price_events(self, price_events):
        """
        Sets the price_events of this PropertyMarketing.

        :param price_events: The price_events of this PropertyMarketing.
        :type: list[PriceEvent]
        """

        self._price_events = price_events

    @property
    def dealers(self):
        """
        Gets the dealers of this PropertyMarketing.

        :return: The dealers of this PropertyMarketing.
        :rtype: list[MarketingDealer]
        """
        return self._dealers

    @dealers.setter
    def dealers(self, dealers):
        """
        Sets the dealers of this PropertyMarketing.

        :param dealers: The dealers of this PropertyMarketing.
        :type: list[MarketingDealer]
        """

        self._dealers = dealers

    @property
    def marketing_start_date(self):
        """
        Gets the marketing_start_date of this PropertyMarketing.

        :return: The marketing_start_date of this PropertyMarketing.
        :rtype: datetime
        """
        return self._marketing_start_date

    @marketing_start_date.setter
    def marketing_start_date(self, marketing_start_date):
        """
        Sets the marketing_start_date of this PropertyMarketing.

        :param marketing_start_date: The marketing_start_date of this PropertyMarketing.
        :type: datetime
        """

        self._marketing_start_date = marketing_start_date

    @property
    def marketing_end_date(self):
        """
        Gets the marketing_end_date of this PropertyMarketing.

        :return: The marketing_end_date of this PropertyMarketing.
        :rtype: datetime
        """
        return self._marketing_end_date

    @marketing_end_date.setter
    def marketing_end_date(self, marketing_end_date):
        """
        Sets the marketing_end_date of this PropertyMarketing.

        :param marketing_end_date: The marketing_end_date of this PropertyMarketing.
        :type: datetime
        """

        self._marketing_end_date = marketing_end_date

    @property
    def publication_start_date(self):
        """
        Gets the publication_start_date of this PropertyMarketing.

        :return: The publication_start_date of this PropertyMarketing.
        :rtype: datetime
        """
        return self._publication_start_date

    @publication_start_date.setter
    def publication_start_date(self, publication_start_date):
        """
        Sets the publication_start_date of this PropertyMarketing.

        :param publication_start_date: The publication_start_date of this PropertyMarketing.
        :type: datetime
        """

        self._publication_start_date = publication_start_date

    @property
    def publication_end_date(self):
        """
        Gets the publication_end_date of this PropertyMarketing.

        :return: The publication_end_date of this PropertyMarketing.
        :rtype: datetime
        """
        return self._publication_end_date

    @publication_end_date.setter
    def publication_end_date(self, publication_end_date):
        """
        Sets the publication_end_date of this PropertyMarketing.

        :param publication_end_date: The publication_end_date of this PropertyMarketing.
        :type: datetime
        """

        self._publication_end_date = publication_end_date

    @property
    def rental_expenses(self):
        """
        Gets the rental_expenses of this PropertyMarketing.

        :return: The rental_expenses of this PropertyMarketing.
        :rtype: float
        """
        return self._rental_expenses

    @rental_expenses.setter
    def rental_expenses(self, rental_expenses):
        """
        Sets the rental_expenses of this PropertyMarketing.

        :param rental_expenses: The rental_expenses of this PropertyMarketing.
        :type: float
        """

        self._rental_expenses = rental_expenses

    @property
    def rental_expenses_included(self):
        """
        Gets the rental_expenses_included of this PropertyMarketing.

        :return: The rental_expenses_included of this PropertyMarketing.
        :rtype: bool
        """
        return self._rental_expenses_included

    @rental_expenses_included.setter
    def rental_expenses_included(self, rental_expenses_included):
        """
        Sets the rental_expenses_included of this PropertyMarketing.

        :param rental_expenses_included: The rental_expenses_included of this PropertyMarketing.
        :type: bool
        """

        self._rental_expenses_included = rental_expenses_included

    @property
    def deposit(self):
        """
        Gets the deposit of this PropertyMarketing.

        :return: The deposit of this PropertyMarketing.
        :rtype: float
        """
        return self._deposit

    @deposit.setter
    def deposit(self, deposit):
        """
        Sets the deposit of this PropertyMarketing.

        :param deposit: The deposit of this PropertyMarketing.
        :type: float
        """

        self._deposit = deposit

    @property
    def property_tax(self):
        """
        Gets the property_tax of this PropertyMarketing.

        :return: The property_tax of this PropertyMarketing.
        :rtype: float
        """
        return self._property_tax

    @property_tax.setter
    def property_tax(self, property_tax):
        """
        Sets the property_tax of this PropertyMarketing.

        :param property_tax: The property_tax of this PropertyMarketing.
        :type: float
        """

        self._property_tax = property_tax

    @property
    def fees(self):
        """
        Gets the fees of this PropertyMarketing.

        :return: The fees of this PropertyMarketing.
        :rtype: float
        """
        return self._fees

    @fees.setter
    def fees(self, fees):
        """
        Sets the fees of this PropertyMarketing.

        :param fees: The fees of this PropertyMarketing.
        :type: float
        """

        self._fees = fees

    @property
    def fees_included(self):
        """
        Gets the fees_included of this PropertyMarketing.

        :return: The fees_included of this PropertyMarketing.
        :rtype: bool
        """
        return self._fees_included

    @fees_included.setter
    def fees_included(self, fees_included):
        """
        Sets the fees_included of this PropertyMarketing.

        :param fees_included: The fees_included of this PropertyMarketing.
        :type: bool
        """

        self._fees_included = fees_included

    @property
    def exclusive_mandate(self):
        """
        Gets the exclusive_mandate of this PropertyMarketing.

        :return: The exclusive_mandate of this PropertyMarketing.
        :rtype: bool
        """
        return self._exclusive_mandate

    @exclusive_mandate.setter
    def exclusive_mandate(self, exclusive_mandate):
        """
        Sets the exclusive_mandate of this PropertyMarketing.

        :param exclusive_mandate: The exclusive_mandate of this PropertyMarketing.
        :type: bool
        """

        self._exclusive_mandate = exclusive_mandate

    @property
    def occupied(self):
        """
        Gets the occupied of this PropertyMarketing.

        :return: The occupied of this PropertyMarketing.
        :rtype: bool
        """
        return self._occupied

    @occupied.setter
    def occupied(self, occupied):
        """
        Sets the occupied of this PropertyMarketing.

        :param occupied: The occupied of this PropertyMarketing.
        :type: bool
        """

        self._occupied = occupied

    @property
    def rent_control(self):
        """
        Gets the rent_control of this PropertyMarketing.

        :return: The rent_control of this PropertyMarketing.
        :rtype: RentControl
        """
        return self._rent_control

    @rent_control.setter
    def rent_control(self, rent_control):
        """
        Sets the rent_control of this PropertyMarketing.

        :param rent_control: The rent_control of this PropertyMarketing.
        :type: RentControl
        """

        self._rent_control = rent_control

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PropertyMarketing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class MandatairesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def mandatary_networks_get(self, **kwargs):
        """
        Rechercher des réseaux mandataires
        Rechercher des réseaux mandataires selon plusieurs critères # Exemples   ## Rechercher le réseau Efficity     /mandatary-networks?q=efficity'
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.mandatary_networks_get(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int _from: Début de la pagination
        :param int size: Nombre de résultats
        :param str sort: Trier par
        :param list[str] includes: Inclure un ou plusieurs élements par identifiant
        :param list[str] excludes: Exclure un ou plusieurs élements par identifiant
        :param str q: Recherche plein-texte
        :param list[str] siren:
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.mandatary_networks_get_with_http_info(**kwargs)
        else:
            (data) = self.mandatary_networks_get_with_http_info(**kwargs)
            return data

    def mandatary_networks_get_with_http_info(self, **kwargs):
        """
        Rechercher des réseaux mandataires
        Rechercher des réseaux mandataires selon plusieurs critères # Exemples   ## Rechercher le réseau Efficity     /mandatary-networks?q=efficity'
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.mandatary_networks_get_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int _from: Début de la pagination
        :param int size: Nombre de résultats
        :param str sort: Trier par
        :param list[str] includes: Inclure un ou plusieurs élements par identifiant
        :param list[str] excludes: Exclure un ou plusieurs élements par identifiant
        :param str q: Recherche plein-texte
        :param list[str] siren:
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'size', 'sort', 'includes', 'excludes', 'q', 'siren']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method mandatary_networks_get" % key
                )
            params[key] = val
        del params['kwargs']

        if '_from' in params and params['_from'] < 0:
            raise ValueError("Invalid value for parameter `_from` when calling `mandatary_networks_get`, must be a value greater than or equal to `0`")
        if 'size' in params and params['size'] > 1000:
            raise ValueError("Invalid value for parameter `size` when calling `mandatary_networks_get`, must be a value less than or equal to `1000`")
        if 'size' in params and params['size'] < 0:
            raise ValueError("Invalid value for parameter `size` when calling `mandatary_networks_get`, must be a value greater than or equal to `0`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))
        if 'size' in params:
            query_params.append(('size', params['size']))
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'includes' in params:
            query_params.append(('includes', params['includes']))
            collection_formats['includes'] = 'multi'
        if 'excludes' in params:
            query_params.append(('excludes', params['excludes']))
            collection_formats['excludes'] = 'multi'
        if 'q' in params:
            query_params.append(('q', params['q']))
        if 'siren' in params:
            query_params.append(('siren', params['siren']))
            collection_formats['siren'] = 'csv'

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/mandatary-networks', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse2006',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def mandatary_networks_id_get(self, id, **kwargs):
        """
        Récupérer un réseau mandataire
        Récupérer un réseau mandataire par son identifiant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.mandatary_networks_id_get(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int id: L'identifiant du réseau de mandataire (required)
        :return: MandataryNetwork
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.mandatary_networks_id_get_with_http_info(id, **kwargs)
        else:
            (data) = self.mandatary_networks_id_get_with_http_info(id, **kwargs)
            return data

    def mandatary_networks_id_get_with_http_info(self, id, **kwargs):
        """
        Récupérer un réseau mandataire
        Récupérer un réseau mandataire par son identifiant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.mandatary_networks_id_get_with_http_info(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int id: L'identifiant du réseau de mandataire (required)
        :return: MandataryNetwork
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method mandatary_networks_id_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `mandatary_networks_id_get`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/mandatary-networks/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='MandataryNetwork',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Address(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'city_id': 'float',
        'street_number': 'str',
        'street': 'str',
        'zip_code': 'str',
        'dept_code': 'str',
        'country': 'str',
        'location': 'Location',
        'approximate_location': 'object'
    }

    attribute_map = {
        'city_id': 'cityId',
        'street_number': 'streetNumber',
        'street': 'street',
        'zip_code': 'zipCode',
        'dept_code': 'deptCode',
        'country': 'country',
        'location': 'location',
        'approximate_location': 'approximateLocation'
    }

    def __init__(self, city_id=None, street_number=None, street=None, zip_code=None, dept_code=None, country=None, location=None, approximate_location=None):
        """
        Address - a model defined in Swagger
        """

        self._city_id = None
        self._street_number = None
        self._street = None
        self._zip_code = None
        self._dept_code = None
        self._country = None
        self._location = None
        self._approximate_location = None

        if city_id is not None:
          self.city_id = city_id
        if street_number is not None:
          self.street_number = street_number
        if street is not None:
          self.street = street
        if zip_code is not None:
          self.zip_code = zip_code
        if dept_code is not None:
          self.dept_code = dept_code
        if country is not None:
          self.country = country
        if location is not None:
          self.location = location
        if approximate_location is not None:
          self.approximate_location = approximate_location

    @property
    def city_id(self):
        """
        Gets the city_id of this Address.

        :return: The city_id of this Address.
        :rtype: float
        """
        return self._city_id

    @city_id.setter
    def city_id(self, city_id):
        """
        Sets the city_id of this Address.

        :param city_id: The city_id of this Address.
        :type: float
        """
        if city_id is not None and city_id < 1:
            raise ValueError("Invalid value for `city_id`, must be a value greater than or equal to `1`")

        self._city_id = city_id

    @property
    def street_number(self):
        """
        Gets the street_number of this Address.

        :return: The street_number of this Address.
        :rtype: str
        """
        return self._street_number

    @street_number.setter
    def street_number(self, street_number):
        """
        Sets the street_number of this Address.

        :param street_number: The street_number of this Address.
        :type: str
        """

        self._street_number = street_number

    @property
    def street(self):
        """
        Gets the street of this Address.

        :return: The street of this Address.
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street):
        """
        Sets the street of this Address.

        :param street: The street of this Address.
        :type: str
        """

        self._street = street

    @property
    def zip_code(self):
        """
        Gets the zip_code of this Address.

        :return: The zip_code of this Address.
        :rtype: str
        """
        return self._zip_code

    @zip_code.setter
    def zip_code(self, zip_code):
        """
        Sets the zip_code of this Address.

        :param zip_code: The zip_code of this Address.
        :type: str
        """

        self._zip_code = zip_code

    @property
    def dept_code(self):
        """
        Gets the dept_code of this Address.

        :return: The dept_code of this Address.
        :rtype: str
        """
        return self._dept_code

    @dept_code.setter
    def dept_code(self, dept_code):
        """
        Sets the dept_code of this Address.

        :param dept_code: The dept_code of this Address.
        :type: str
        """

        self._dept_code = dept_code

    @property
    def country(self):
        """
        Gets the country of this Address.

        :return: The country of this Address.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Address.

        :param country: The country of this Address.
        :type: str
        """

        self._country = country

    @property
    def location(self):
        """
        Gets the location of this Address.

        :return: The location of this Address.
        :rtype: Location
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this Address.

        :param location: The location of this Address.
        :type: Location
        """

        self._location = location

    @property
    def approximate_location(self):
        """
        Gets the approximate_location of this Address.

        :return: The approximate_location of this Address.
        :rtype: object
        """
        return self._approximate_location

    @approximate_location.setter
    def approximate_location(self, approximate_location):
        """
        Sets the approximate_location of this Address.

        :param approximate_location: The approximate_location of this Address.
        :type: object
        """

        self._approximate_location = approximate_location

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Address):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from __future__ import absolute_import

# import apis into api package
from .agences_api import AgencesApi
from .annonces_api import AnnoncesApi
from .biens_api import BiensApi
from .bienssimilaires_api import BienssimilairesApi
from .encadrementloyers_api import EncadrementloyersApi
from .etudes_api import EtudesApi
from .evenementsadbox_api import EvenementsadboxApi
from .mandataires_api import MandatairesApi
from .utilisateurs_api import UtilisateursApi
from .villes_api import VillesApi



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class RentControlZone(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'observatory_id': 'int',
        'iris_quarter_ids': 'list[str]',
        'room_count_category': 'Range',
        'construction_period': 'Range',
        'furnished': 'bool',
        'median': 'float'
    }

    attribute_map = {
        'id': 'id',
        'observatory_id': 'observatoryId',
        'iris_quarter_ids': 'irisQuarterIds',
        'room_count_category': 'roomCountCategory',
        'construction_period': 'constructionPeriod',
        'furnished': 'furnished',
        'median': 'median'
    }

    def __init__(self, id=None, observatory_id=None, iris_quarter_ids=None, room_count_category=None, construction_period=None, furnished=None, median=None):
        """
        RentControlZone - a model defined in Swagger
        """

        self._id = None
        self._observatory_id = None
        self._iris_quarter_ids = None
        self._room_count_category = None
        self._construction_period = None
        self._furnished = None
        self._median = None

        if id is not None:
          self.id = id
        if observatory_id is not None:
          self.observatory_id = observatory_id
        if iris_quarter_ids is not None:
          self.iris_quarter_ids = iris_quarter_ids
        if room_count_category is not None:
          self.room_count_category = room_count_category
        if construction_period is not None:
          self.construction_period = construction_period
        if furnished is not None:
          self.furnished = furnished
        if median is not None:
          self.median = median

    @property
    def id(self):
        """
        Gets the id of this RentControlZone.

        :return: The id of this RentControlZone.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RentControlZone.

        :param id: The id of this RentControlZone.
        :type: int
        """

        self._id = id

    @property
    def observatory_id(self):
        """
        Gets the observatory_id of this RentControlZone.

        :return: The observatory_id of this RentControlZone.
        :rtype: int
        """
        return self._observatory_id

    @observatory_id.setter
    def observatory_id(self, observatory_id):
        """
        Sets the observatory_id of this RentControlZone.

        :param observatory_id: The observatory_id of this RentControlZone.
        :type: int
        """

        self._observatory_id = observatory_id

    @property
    def iris_quarter_ids(self):
        """
        Gets the iris_quarter_ids of this RentControlZone.

        :return: The iris_quarter_ids of this RentControlZone.
        :rtype: list[str]
        """
        return self._iris_quarter_ids

    @iris_quarter_ids.setter
    def iris_quarter_ids(self, iris_quarter_ids):
        """
        Sets the iris_quarter_ids of this RentControlZone.

        :param iris_quarter_ids: The iris_quarter_ids of this RentControlZone.
        :type: list[str]
        """

        self._iris_quarter_ids = iris_quarter_ids

    @property
    def room_count_category(self):
        """
        Gets the room_count_category of this RentControlZone.

        :return: The room_count_category of this RentControlZone.
        :rtype: Range
        """
        return self._room_count_category

    @room_count_category.setter
    def room_count_category(self, room_count_category):
        """
        Sets the room_count_category of this RentControlZone.

        :param room_count_category: The room_count_category of this RentControlZone.
        :type: Range
        """

        self._room_count_category = room_count_category

    @property
    def construction_period(self):
        """
        Gets the construction_period of this RentControlZone.

        :return: The construction_period of this RentControlZone.
        :rtype: Range
        """
        return self._construction_period

    @construction_period.setter
    def construction_period(self, construction_period):
        """
        Sets the construction_period of this RentControlZone.

        :param construction_period: The construction_period of this RentControlZone.
        :type: Range
        """

        self._construction_period = construction_period

    @property
    def furnished(self):
        """
        Gets the furnished of this RentControlZone.

        :return: The furnished of this RentControlZone.
        :rtype: bool
        """
        return self._furnished

    @furnished.setter
    def furnished(self, furnished):
        """
        Sets the furnished of this RentControlZone.

        :param furnished: The furnished of this RentControlZone.
        :type: bool
        """

        self._furnished = furnished

    @property
    def median(self):
        """
        Gets the median of this RentControlZone.

        :return: The median of this RentControlZone.
        :rtype: float
        """
        return self._median

    @median.setter
    def median(self, median):
        """
        Sets the median of this RentControlZone.

        :param median: The median of this RentControlZone.
        :type: float
        """

        self._median = median

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RentControlZone):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
